HpkeContext

Struct HpkeContext 

pub struct HpkeContext {
    private_key: StaticSecret,
}
A context for performing E2E encryption using X25519 and ChaCha20Poly1305.

Fields

private_key: StaticSecret

Implementations

Source

impl HpkeContext

pub fn new() -> Result<Self>

Generates a new keypair.

This will create a new HpkeContext with a randomly generated X25519 keypair.

Errors

This function will return an error if the key generation fails.

pub fn from_private_key(private_key_bytes: &[u8]) -> Result<Self>

Loads a keypair from existing private key bytes.

Arguments
  • private_key_bytes - A 32-byte slice representing the private key.
Errors

This function will return an error if the private key is not 32 bytes long.

pub fn public_key_bytes(&self) -> Vec<u8>

Returns the public key bytes corresponding to our private key.

pub fn private_key_bytes(&self) -> Vec<u8>

Returns the private key bytes.

pub fn seal(&self, recipient_pub: &[u8], plaintext: &[u8]) -> Result<Vec<u8>>

Derives a shared secret and uses it to encrypt a message for a recipient.

Arguments
  • recipient_pub - The public key of the recipient.
  • plaintext - The data to encrypt.
Returns

A vector containing the nonce and the ciphertext.

Errors

This function will return an error if encryption fails.

pub fn open(&self, sender_pub: &[u8], ciphertext: &[u8]) -> Result<Vec<u8>>

Derives a shared secret and uses it to decrypt a message from a sender.

Arguments
  • sender_pub - The public key of the sender.
  • ciphertext - The data to decrypt (nonce prepended).
Returns

A vector containing the plaintext.

Errors

This function will return an error if decryption fails.

fn parse_public_key(&self, key_bytes: &[u8]) -> Result<PublicKey>

Parses a public key from a byte slice.

fn derive_symmetric_key(&self, shared_secret: &SharedSecret) -> Key

Derives a symmetric key from a shared secret.