pub struct HpkeContext {
private_key: StaticSecret,
}Expand description
A context for performing E2E encryption using X25519 and ChaCha20Poly1305.
Fields
private_key: StaticSecretImplementations
Sourceimpl HpkeContext
impl HpkeContext
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Generates a new keypair.
This will create a new HpkeContext with a randomly generated X25519 keypair.
Errors
This function will return an error if the key generation fails.
Sourcepub fn from_private_key(private_key_bytes: &[u8]) -> Result<Self>
pub fn from_private_key(private_key_bytes: &[u8]) -> Result<Self>
Sourcepub fn public_key_bytes(&self) -> Vec<u8> ⓘ
pub fn public_key_bytes(&self) -> Vec<u8> ⓘ
Returns the public key bytes corresponding to our private key.
Sourcepub fn private_key_bytes(&self) -> Vec<u8> ⓘ
pub fn private_key_bytes(&self) -> Vec<u8> ⓘ
Returns the private key bytes.
Sourcefn parse_public_key(&self, key_bytes: &[u8]) -> Result<PublicKey>
fn parse_public_key(&self, key_bytes: &[u8]) -> Result<PublicKey>
Parses a public key from a byte slice.
Sourcefn derive_symmetric_key(&self, shared_secret: &SharedSecret) -> Key
fn derive_symmetric_key(&self, shared_secret: &SharedSecret) -> Key
Derives a symmetric key from a shared secret.